@@ -1,7 +1,10 @@
 package Org::To::VCF;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.07'; # VERSION
+
 use 5.010001;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use vars qw($VERSION);
 
@@ -20,9 +23,6 @@ has export_notes => (is => 'rw');
 has _vcf => (is => 'rw'); # vcf object
 has _cccode => (is => 'rw'); # country calling code
 
-our $VERSION = '0.06'; # VERSION
-our $DATE = '2014-08-16'; # DATE
-
 require Exporter;
 our @ISA;
 push @ISA,       qw(Exporter);
@@ -381,7 +381,7 @@ Org::To::VCF - Export contacts in Org document to VCF (vCard addressbook)
 
 =head1 VERSION
 
-This document describes version 0.06 of Org::To::VCF (from Perl distribution Org-To-VCF), released on 2014-08-16.
+This document describes version 0.07 of Org::To::VCF (from Perl distribution Org-To-VCF), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -437,7 +437,7 @@ drawer:
 
 =head2 org_to_vcf(%args) -> [status, msg, result, meta]
 
-Export contacts in Org document to VCF (vCard addressbook).
+{en_US Export contacts in Org document to VCF (vCard addressbook)}.
 
 Arguments ('*' denotes required arguments):
 
@@ -445,56 +445,62 @@ Arguments ('*' denotes required arguments):
 
 =item * B<default_country> => I<str>
 
-Specify default country code.
+{en_US Specify default country code}.
 
+{en_US 
 Free-form phone numbers on phone fields are formatted by this function, e.g.
 C<081 123 4567> becomes C<0811234567>. If default country is specified (e.g.
 "ID"), the number will be formatted as C<+62811234567>. Setting this option is
 recommended so the phone numbers are nicely formatted as international number.
+}
 
-=item * B<exclude_tags> => I<array>
+=item * B<exclude_tags> => I<array[str]>
 
-Exclude trees that carry one of these tags.
+{en_US Exclude trees that carry one of these tags}.
 
+{en_US 
 If the whole document doesn't have any of these tags, then the whole document
 will be exported. Otherwise, trees that do not carry one of these tags will be
 excluded. If a selected tree is a subtree, the heading hierarchy above it will
 also be selected for export, but not the text below those headings.
 
 exclude_tags is evaluated after include_tags.
+}
 
 =item * B<export_notes> => I<bool> (default: 1)
 
-Whether to export note fields.
+{en_US Whether to export note fields}.
 
-=item * B<include_tags> => I<array>
+=item * B<include_tags> => I<array[str]>
 
-Include trees that carry one of these tags.
+{en_US Include trees that carry one of these tags}.
 
+{en_US 
 Works like Org's 'org-export-select-tags' variable. If the whole document
 doesn't have any of these tags, then the whole document will be exported.
 Otherwise, trees that do not carry one of these tags will be excluded. If a
 selected tree is a subtree, the heading hierarchy above it will also be selected
 for export, but not the text below those headings.
+}
 
 =item * B<source_file> => I<str>
 
-Source Org file to export.
+{en_US Source Org file to export}.
 
 =item * B<source_str> => I<str>
 
-Alternatively you can specify Org string directly.
+{en_US Alternatively you can specify Org string directly}.
 
 =item * B<target_file> => I<str>
 
-VCF file to write to.
+{en_US VCF file to write to}.
 
+{en_US 
 If not specified, VCF output string will be returned instead.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -504,17 +510,10 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =for Pod::Coverage ^(default_country|export|export_.+)$
 
-=head1 TODO
-
-This is an early release. An important node, addresses (ADR), not parsed yet
-because my use case is currently for phone's phonebook.
-
-Other unimplemented nodes are listed in the source code.
-
 =head1 SEE ALSO
 
 For more information about Org document format, visit http://orgmode.org/
@@ -531,7 +530,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-VCF
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-VCF>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-VCF>.
 
 =head1 BUGS
 
@@ -543,11 +542,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
